@@ -12,10 +12,11 @@ except ImportError:
 
 def _interactive_test():
     with gzip.GzipFile(os.path.join(here, '..', 'cities.gz')) as input_file:
-        f = FuzzySet((line.strip() for line in input_file))
+        f = FuzzySet((line.strip().decode() for line in input_file))
     while True:
-        town = raw_input("Enter town name: ")
-        print f.get(town)
+        town = input("Enter town name: ")
+        print(f.get(town))
+
 
 if __name__ == '__main__':
     _interactive_test()
