@@ -4,16 +4,14 @@ import gzip
 import timeit
 import random
 import texttable
-
-here = os.path.dirname(__file__)
-
 import fuzzyset
 import cfuzzyset
 
+here = os.path.dirname(__file__)
 test_data = [[], 0]
 
 def run_tests():
-    print 'Building data structures...'
+    print('Building data structures...')
     structures = build_structures()
     results = {}
     names = {}
@@ -23,7 +21,7 @@ def run_tests():
         names[varname] = name
     lengths = (3, 6, 10, 15, 25, 50)
     num_tests = 5000
-    print 'Starting the timing tests...'
+    print('Starting the timing tests...')
     for length in lengths:
         test_data_l = [None] * num_tests
         test_data[0] = test_data_l
@@ -48,7 +46,7 @@ def run_tests():
                        [[name] + [results[varname][i] / num_tests for i, length in enumerate(lengths)]
                         for varname, name, _ in structures])
 
-    print table.draw()
+    print(table.draw())
 
 string = 'abcdefghjijklmnopqrstuvwxyz'
 
@@ -67,7 +65,7 @@ def build_structures():
     ref = {}
     input_file = gzip.GzipFile(os.path.join(here, '..', 'cities.gz'))
     for line in input_file:
-        line = line.rstrip()
+        line = line.rstrip().decode()
         for _, _, structure in opts:
             structure.add(line)
         ref[line] = line
